==> hem-0.0.7.tgz: package/lib/hem.js <==
(function() {
  var Dependencies, Package, Stitch, compilers, eco, fs, stitch, toArray, uglify;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  fs = require('fs');
  eco = require('eco');
  uglify = require('uglify-js');
  compilers = require('./compilers');
  stitch = require('../assets/stitch');
  Dependencies = require('./dependencies');
  Stitch = require('./stitch');
  toArray = require('./utils').toArray;
  Package = (function() {
    function Package(config) {
      var _ref;
      if (config == null) {
        config = {};
      }
      this.identifier = (_ref = config.identifier) != null ? _ref : 'require';
      this.libs = toArray(config.libs);
      this.paths = toArray(config.paths);
      this.dependencies = toArray(config.dependencies);
    }
    Package.prototype.compileModules = function() {
      this.dependency || (this.dependency = new Dependencies(this.dependencies));
      this.stitch = new Stitch(this.paths);
      this.modules = this.dependency.resolve().concat(this.stitch.resolve());
      return stitch({
        identifier: this.identifier,
        modules: this.modules
      });
    };
    Package.prototype.compileLibs = function() {
      var path;
      return ((function() {
        var _i, _len, _ref, _results;
        _ref = this.libs;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          path = _ref[_i];
          _results.push(fs.readFileSync(path, 'utf8'));
        }
        return _results;
      }).call(this)).join("\n");
    };
    Package.prototype.compile = function(compress) {
      var content;
      if (compress == null) {
        compress = false;
      }
      content = [this.compileLibs(), this.compileModules()].join("\n");
      if (compress) {
        content = uglify(content);
      }
      return content;
    };
    Package.prototype.createServer = function() {
      return __bind(function(req, res, next) {
        var content;
        content = this.compile();
        res.writeHead(200, {
          'Content-Type': 'text/javascript'
        });
        return res.end(content);
      }, this);
    };
    return Package;
  })();
  module.exports = {
    compilers: compilers,
    Package: Package,
    createPackage: function(config) {
      return new Package(config);
    }
  };
}).call(this);

==> hem-0.0.9.tgz: package/lib/hem.js <==
(function() {
  var Dependency, Package, Stitch, compilers, eco, fs, stitch, toArray, uglify;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  fs = require('fs');
  eco = require('eco');
  uglify = require('uglify-js');
  compilers = require('./compilers');
  stitch = require('../assets/stitch');
  Dependency = require('./dependency');
  Stitch = require('./stitch');
  toArray = require('./utils').toArray;
  Package = (function() {
    function Package(config) {
      var _ref;
      if (config == null) {
        config = {};
      }
      this.identifier = (_ref = config.identifier) != null ? _ref : 'require';
      this.libs = toArray(config.libs);
      this.paths = toArray(config.paths);
      this.dependencies = toArray(config.dependencies);
    }
    Package.prototype.compileModules = function() {
      this.dependency || (this.dependency = new Dependency(this.dependencies));
      this.stitch = new Stitch(this.paths);
      this.modules = this.dependency.resolve().concat(this.stitch.resolve());
      return stitch({
        identifier: this.identifier,
        modules: this.modules
      });
    };
    Package.prototype.compileLibs = function() {
      var path;
      return ((function() {
        var _i, _len, _ref, _results;
        _ref = this.libs;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          path = _ref[_i];
          _results.push(fs.readFileSync(path, 'utf8'));
        }
        return _results;
      }).call(this)).join("\n");
    };
    Package.prototype.compile = function(compress) {
      var content;
      if (compress == null) {
        compress = false;
      }
      content = [this.compileLibs(), this.compileModules()].join("\n");
      if (compress) {
        content = uglify(content);
      }
      return content;
    };
    Package.prototype.createServer = function() {
      return __bind(function(req, res, next) {
        var content;
        content = this.compile();
        res.writeHead(200, {
          'Content-Type': 'text/javascript'
        });
        return res.end(content);
      }, this);
    };
    return Package;
  })();
  module.exports = {
    compilers: compilers,
    Package: Package,
    createPackage: function(config) {
      return new Package(config);
    }
  };
}).call(this);
